Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(947)

Unified Diff: src/compiler/linkage.h

Issue 1811283003: [wasm] WIP fix arm64 frame alignment. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/instruction-selector.cc ('k') | src/compiler/wasm-compiler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/linkage.h
diff --git a/src/compiler/linkage.h b/src/compiler/linkage.h
index 01911e6ee246b33c08983001a5fc2d51c1d5b319..a0434f8afff6c2651bf8ac60e7f588c07bb77c28 100644
--- a/src/compiler/linkage.h
+++ b/src/compiler/linkage.h
@@ -160,10 +160,11 @@ class CallDescriptor final : public ZoneObject {
kCanUseRoots = 1u << 6,
// (arm64 only) native stack should be used for arguments.
kUseNativeStack = 1u << 7,
// (arm64 only) call instruction has to restore JSSP.
kRestoreJSSP = 1u << 8,
+ kRestoreCSP = 1u << 9,
// Causes the code generator to initialize the root register.
- kInitializeRootRegister = 1u << 9,
+ kInitializeRootRegister = 1u << 10,
kPatchableCallSiteWithNop = kPatchableCallSite | kNeedsNopAfterCall
};
typedef base::Flags<Flag> Flags;
@@ -160,10 +160,11 @@ class CallDescriptor final : public ZoneObject {
// (arm64 only) native stack should be used for arguments.
kUseNativeStack = 1u << 7,
- // (arm64 only) call instruction has to restore JSSP.
+ // (arm64 only) call instruction has to restore JSSP or CSP.
kRestoreJSSP = 1u << 8,
« no previous file with comments | « src/compiler/instruction-selector.cc ('k') | src/compiler/wasm-compiler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698